@@ -2,8 +2,8 @@
 # Created by makepy.py version 0.5.01
 # By python version 3.8.10 (tags/v3.8.10:3d8993a, May  3 2021, 11:48:03) [MSC v.1928 64 bit (AMD64)]
 # From type library 'RecurDynCOMFlexInterface.tlb'
-# On Tue Jun 28 10:10:45 2022
-'RecurDyn V9R5 RecurDynCOMFlexInterface Type Library'
+# On Mon Feb  6 02:20:43 2023
+'RecurDyn V10R1 RecurDynCOMFlexInterface Type Library'
 makepy_version = '0.5.01'
 python_version = 0x3080af0
 
@@ -252,8 +252,8 @@ class IRFlexGenerationOption(DispatchBaseClass):
 		return self._ApplyTypes_(*(9515, 2, (11, 0), (), "RemoveMidNodeRelatedInformationFlag", None))
 	def _get_RemoveZeroValueForRotModeShapeFlag(self):
 		return self._ApplyTypes_(*(9516, 2, (11, 0), (), "RemoveZeroValueForRotModeShapeFlag", None))
-	def _get_SMPThreadNo(self):
-		return self._ApplyTypes_(*(9538, 2, (19, 0), (), "SMPThreadNo", None))
+	def _get_SMPComputingNoThread(self):
+		return self._ApplyTypes_(*(9539, 2, (19, 0), (), "SMPComputingNoThread", None))
 	def _get_SavedModeNumber(self):
 		return self._ApplyTypes_(*(9525, 2, (19, 0), (), "SavedModeNumber", None))
 	def _get_ShellDrillingParameter(self):
@@ -266,6 +266,8 @@ class IRFlexGenerationOption(DispatchBaseClass):
 		return self._ApplyTypes_(*(9537, 2, (11, 0), (), "SingularCheckMaxRatioFlag", None))
 	def _get_Solver(self):
 		return self._ApplyTypes_(*(9501, 2, (3, 0), (), "Solver", '{751C1136-D0D2-41B4-98DF-2C88CE95D9C4}'))
+	def _get_StopSimulationWhenLowMeshQualityFlag(self):
+		return self._ApplyTypes_(*(9538, 2, (11, 0), (), "StopSimulationWhenLowMeshQualityFlag", None))
 	def _get_StrainShapeFlag(self):
 		return self._ApplyTypes_(*(9522, 2, (11, 0), (), "StrainShapeFlag", None))
 	def _get_StressShapeFlag(self):
@@ -358,9 +360,9 @@ class IRFlexGenerationOption(DispatchBaseClass):
 	def _set_RemoveZeroValueForRotModeShapeFlag(self, value):
 		if "RemoveZeroValueForRotModeShapeFlag" in self.__dict__: self.__dict__["RemoveZeroValueForRotModeShapeFlag"] = value; return
 		self._oleobj_.Invoke(*((9516, LCID, 4, 0) + (value,) + ()))
-	def _set_SMPThreadNo(self, value):
-		if "SMPThreadNo" in self.__dict__: self.__dict__["SMPThreadNo"] = value; return
-		self._oleobj_.Invoke(*((9538, LCID, 4, 0) + (value,) + ()))
+	def _set_SMPComputingNoThread(self, value):
+		if "SMPComputingNoThread" in self.__dict__: self.__dict__["SMPComputingNoThread"] = value; return
+		self._oleobj_.Invoke(*((9539, LCID, 4, 0) + (value,) + ()))
 	def _set_SavedModeNumber(self, value):
 		if "SavedModeNumber" in self.__dict__: self.__dict__["SavedModeNumber"] = value; return
 		self._oleobj_.Invoke(*((9525, LCID, 4, 0) + (value,) + ()))
@@ -379,6 +381,9 @@ class IRFlexGenerationOption(DispatchBaseClass):
 	def _set_Solver(self, value):
 		if "Solver" in self.__dict__: self.__dict__["Solver"] = value; return
 		self._oleobj_.Invoke(*((9501, LCID, 4, 0) + (value,) + ()))
+	def _set_StopSimulationWhenLowMeshQualityFlag(self, value):
+		if "StopSimulationWhenLowMeshQualityFlag" in self.__dict__: self.__dict__["StopSimulationWhenLowMeshQualityFlag"] = value; return
+		self._oleobj_.Invoke(*((9538, LCID, 4, 0) + (value,) + ()))
 	def _set_StrainShapeFlag(self, value):
 		if "StrainShapeFlag" in self.__dict__: self.__dict__["StrainShapeFlag"] = value; return
 		self._oleobj_.Invoke(*((9522, LCID, 4, 0) + (value,) + ()))
@@ -546,9 +551,9 @@ class IRFlexGenerationOption(DispatchBaseClass):
 
 	:type: bool
 	'''
-	SMPThreadNo = property(_get_SMPThreadNo, _set_SMPThreadNo)
+	SMPComputingNoThread = property(_get_SMPComputingNoThread, _set_SMPComputingNoThread)
 	'''
-	Number of SMP thread
+	SMP Computing No. Thread
 
 	:type: int
 	'''
@@ -584,10 +589,16 @@ class IRFlexGenerationOption(DispatchBaseClass):
 	'''
 	Solver = property(_get_Solver, _set_Solver)
 	'''
-	Solver
+	Solver is obsolete function
 
 	:type: recurdyn.FlexInterface.RFISolverType
 	'''
+	StopSimulationWhenLowMeshQualityFlag = property(_get_StopSimulationWhenLowMeshQualityFlag, _set_StopSimulationWhenLowMeshQualityFlag)
+	'''
+	Stop Simulation When Low Mesh Quality Flag
+
+	:type: bool
+	'''
 	StrainShapeFlag = property(_get_StrainShapeFlag, _set_StrainShapeFlag)
 	'''
 	Strain Shape Flag
@@ -655,13 +666,14 @@ class IRFlexGenerationOption(DispatchBaseClass):
 		"_set_RefFrame": _set_RefFrame,
 		"_set_RemoveMidNodeRelatedInformationFlag": _set_RemoveMidNodeRelatedInformationFlag,
 		"_set_RemoveZeroValueForRotModeShapeFlag": _set_RemoveZeroValueForRotModeShapeFlag,
-		"_set_SMPThreadNo": _set_SMPThreadNo,
+		"_set_SMPComputingNoThread": _set_SMPComputingNoThread,
 		"_set_SavedModeNumber": _set_SavedModeNumber,
 		"_set_ShellDrillingParameter": _set_ShellDrillingParameter,
 		"_set_ShellRecoveryType": _set_ShellRecoveryType,
 		"_set_SingularCheckMaxRatio": _set_SingularCheckMaxRatio,
 		"_set_SingularCheckMaxRatioFlag": _set_SingularCheckMaxRatioFlag,
 		"_set_Solver": _set_Solver,
+		"_set_StopSimulationWhenLowMeshQualityFlag": _set_StopSimulationWhenLowMeshQualityFlag,
 		"_set_StrainShapeFlag": _set_StrainShapeFlag,
 		"_set_StressShapeFlag": _set_StressShapeFlag,
 		"_set_Unit": _set_Unit,
@@ -695,13 +707,14 @@ class IRFlexGenerationOption(DispatchBaseClass):
 		"RefFrame": (9505, 2, (9, 0), (), "RefFrame", '{6A3295D9-E76B-473C-9655-23B7B1CBD671}'),
 		"RemoveMidNodeRelatedInformationFlag": (9515, 2, (11, 0), (), "RemoveMidNodeRelatedInformationFlag", None),
 		"RemoveZeroValueForRotModeShapeFlag": (9516, 2, (11, 0), (), "RemoveZeroValueForRotModeShapeFlag", None),
-		"SMPThreadNo": (9538, 2, (19, 0), (), "SMPThreadNo", None),
+		"SMPComputingNoThread": (9539, 2, (19, 0), (), "SMPComputingNoThread", None),
 		"SavedModeNumber": (9525, 2, (19, 0), (), "SavedModeNumber", None),
 		"ShellDrillingParameter": (9520, 2, (5, 0), (), "ShellDrillingParameter", None),
 		"ShellRecoveryType": (9523, 2, (3, 0), (), "ShellRecoveryType", '{D21798C7-4AF1-416C-8CAC-FB9483D6C2CC}'),
 		"SingularCheckMaxRatio": (9536, 2, (5, 0), (), "SingularCheckMaxRatio", None),
 		"SingularCheckMaxRatioFlag": (9537, 2, (11, 0), (), "SingularCheckMaxRatioFlag", None),
 		"Solver": (9501, 2, (3, 0), (), "Solver", '{751C1136-D0D2-41B4-98DF-2C88CE95D9C4}'),
+		"StopSimulationWhenLowMeshQualityFlag": (9538, 2, (11, 0), (), "StopSimulationWhenLowMeshQualityFlag", None),
 		"StrainShapeFlag": (9522, 2, (11, 0), (), "StrainShapeFlag", None),
 		"StressShapeFlag": (9521, 2, (11, 0), (), "StressShapeFlag", None),
 		"Unit": (9514, 2, (9, 0), (), "Unit", '{09A65909-6FBB-488A-9726-D320F5666395}'),
@@ -734,13 +747,14 @@ class IRFlexGenerationOption(DispatchBaseClass):
 		"RefFrame": ((9505, LCID, 4, 0),()),
 		"RemoveMidNodeRelatedInformationFlag": ((9515, LCID, 4, 0),()),
 		"RemoveZeroValueForRotModeShapeFlag": ((9516, LCID, 4, 0),()),
-		"SMPThreadNo": ((9538, LCID, 4, 0),()),
+		"SMPComputingNoThread": ((9539, LCID, 4, 0),()),
 		"SavedModeNumber": ((9525, LCID, 4, 0),()),
 		"ShellDrillingParameter": ((9520, LCID, 4, 0),()),
 		"ShellRecoveryType": ((9523, LCID, 4, 0),()),
 		"SingularCheckMaxRatio": ((9536, LCID, 4, 0),()),
 		"SingularCheckMaxRatioFlag": ((9537, LCID, 4, 0),()),
 		"Solver": ((9501, LCID, 4, 0),()),
+		"StopSimulationWhenLowMeshQualityFlag": ((9538, LCID, 4, 0),()),
 		"StrainShapeFlag": ((9522, LCID, 4, 0),()),
 		"StressShapeFlag": ((9521, LCID, 4, 0),()),
 		"Unit": ((9514, LCID, 4, 0),()),
@@ -882,8 +896,10 @@ IRFlexGenerationOption_vtables_ = [
 	(( 'SingularCheckMaxRatio' , 'pVal' , ), 9536, (9536, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 616 , (3, 0, None, None) , 0 , )),
 	(( 'SingularCheckMaxRatioFlag' , 'pVal' , ), 9537, (9537, (), [ (11, 1, None, None) , ], 1 , 4 , 4 , 0 , 624 , (3, 0, None, None) , 0 , )),
 	(( 'SingularCheckMaxRatioFlag' , 'pVal' , ), 9537, (9537, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 632 , (3, 0, None, None) , 0 , )),
-	(( 'SMPThreadNo' , 'pVal' , ), 9538, (9538, (), [ (19, 1, None, None) , ], 1 , 4 , 4 , 0 , 640 , (3, 0, None, None) , 0 , )),
-	(( 'SMPThreadNo' , 'pVal' , ), 9538, (9538, (), [ (16403, 10, None, None) , ], 1 , 2 , 4 , 0 , 648 , (3, 0, None, None) , 0 , )),
+	(( 'StopSimulationWhenLowMeshQualityFlag' , 'bValue' , ), 9538, (9538, (), [ (11, 1, None, None) , ], 1 , 4 , 4 , 0 , 640 , (3, 0, None, None) , 0 , )),
+	(( 'StopSimulationWhenLowMeshQualityFlag' , 'bValue' , ), 9538, (9538, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 648 , (3, 0, None, None) , 0 , )),
+	(( 'SMPComputingNoThread' , 'uiValue' , ), 9539, (9539, (), [ (19, 1, None, None) , ], 1 , 4 , 4 , 0 , 656 , (3, 0, None, None) , 0 , )),
+	(( 'SMPComputingNoThread' , 'uiValue' , ), 9539, (9539, (), [ (16403, 10, None, None) , ], 1 , 2 , 4 , 0 , 664 , (3, 0, None, None) , 0 , )),
 ]
 
 IRFlexGenerator_vtables_dispatch_ = 1
