@@ -2,8 +2,8 @@
 # Created by makepy.py version 0.5.01
 # By python version 3.8.10 (tags/v3.8.10:3d8993a, May  3 2021, 11:48:03) [MSC v.1928 64 bit (AMD64)]
 # From type library 'RecurDynCOMTire.tlb'
-# On Tue Jun 28 10:10:45 2022
-'RecurDyn V9R5 RecurDynCOMTire Type Library'
+# On Mon Feb  6 02:20:43 2023
+'RecurDyn V10R1 RecurDynCOMTire Type Library'
 makepy_version = '0.5.01'
 python_version = 0x3080af0
 
@@ -291,6 +291,8 @@ class ITireGeometryRim(DispatchBaseClass):
 		return self._ApplyTypes_(*(4053, 2, (5, 0), (), "RimWidthUnitMM", None))
 	def _get_UserData(self):
 		return self._ApplyTypes_(*(107, 2, (8, 0), (), "UserData", None))
+	def _get_VertexCollection(self):
+		return self._ApplyTypes_(*(155, 2, (9, 0), (), "VertexCollection", '{BD9F9B20-94B2-4BC3-BB29-0CE3F2B9ADED}'))
 
 	def _set_Comment(self, value):
 		if "Comment" in self.__dict__: self.__dict__["Comment"] = value; return
@@ -386,6 +388,7 @@ class ITireGeometryRim(DispatchBaseClass):
 
 	:type: str
 	'''
+	VertexCollection = property(_get_VertexCollection, None)
 
 	_prop_map_set_function_ = {
 		"_set_Comment": _set_Comment,
@@ -408,6 +411,7 @@ class ITireGeometryRim(DispatchBaseClass):
 		"RimWidth": (4051, 2, (9, 0), (), "RimWidth", '{2B5166E3-4B31-4607-B157-BE237A670336}'),
 		"RimWidthUnitMM": (4053, 2, (5, 0), (), "RimWidthUnitMM", None),
 		"UserData": (107, 2, (8, 0), (), "UserData", None),
+		"VertexCollection": (155, 2, (9, 0), (), "VertexCollection", '{BD9F9B20-94B2-4BC3-BB29-0CE3F2B9ADED}'),
 	}
 	_prop_map_put_ = {
 		"Comment": ((102, LCID, 4, 0),()),
@@ -502,6 +506,8 @@ class ITireGeometryRimGeneric(DispatchBaseClass):
 		return self._ApplyTypes_(*(4053, 2, (5, 0), (), "RimWidthUnitMM", None))
 	def _get_UserData(self):
 		return self._ApplyTypes_(*(107, 2, (8, 0), (), "UserData", None))
+	def _get_VertexCollection(self):
+		return self._ApplyTypes_(*(155, 2, (9, 0), (), "VertexCollection", '{BD9F9B20-94B2-4BC3-BB29-0CE3F2B9ADED}'))
 
 	def _set_Comment(self, value):
 		if "Comment" in self.__dict__: self.__dict__["Comment"] = value; return
@@ -627,6 +633,7 @@ class ITireGeometryRimGeneric(DispatchBaseClass):
 
 	:type: str
 	'''
+	VertexCollection = property(_get_VertexCollection, None)
 
 	_prop_map_set_function_ = {
 		"_set_Comment": _set_Comment,
@@ -655,6 +662,7 @@ class ITireGeometryRimGeneric(DispatchBaseClass):
 		"RimWidth": (4051, 2, (9, 0), (), "RimWidth", '{2B5166E3-4B31-4607-B157-BE237A670336}'),
 		"RimWidthUnitMM": (4053, 2, (5, 0), (), "RimWidthUnitMM", None),
 		"UserData": (107, 2, (8, 0), (), "UserData", None),
+		"VertexCollection": (155, 2, (9, 0), (), "VertexCollection", '{BD9F9B20-94B2-4BC3-BB29-0CE3F2B9ADED}'),
 	}
 	_prop_map_put_ = {
 		"Comment": ((102, LCID, 4, 0),()),
@@ -752,6 +760,8 @@ class ITireGeometryTire(DispatchBaseClass):
 		return self._ApplyTypes_(*(4054, 2, (5, 0), (), "SectionWidthUnitMM", None))
 	def _get_UserData(self):
 		return self._ApplyTypes_(*(107, 2, (8, 0), (), "UserData", None))
+	def _get_VertexCollection(self):
+		return self._ApplyTypes_(*(155, 2, (9, 0), (), "VertexCollection", '{BD9F9B20-94B2-4BC3-BB29-0CE3F2B9ADED}'))
 
 	def _set_Comment(self, value):
 		if "Comment" in self.__dict__: self.__dict__["Comment"] = value; return
@@ -853,6 +863,7 @@ class ITireGeometryTire(DispatchBaseClass):
 
 	:type: str
 	'''
+	VertexCollection = property(_get_VertexCollection, None)
 
 	_prop_map_set_function_ = {
 		"_set_Comment": _set_Comment,
@@ -876,6 +887,7 @@ class ITireGeometryTire(DispatchBaseClass):
 		"SectionWidth": (4051, 2, (9, 0), (), "SectionWidth", '{2B5166E3-4B31-4607-B157-BE237A670336}'),
 		"SectionWidthUnitMM": (4054, 2, (5, 0), (), "SectionWidthUnitMM", None),
 		"UserData": (107, 2, (8, 0), (), "UserData", None),
+		"VertexCollection": (155, 2, (9, 0), (), "VertexCollection", '{BD9F9B20-94B2-4BC3-BB29-0CE3F2B9ADED}'),
 	}
 	_prop_map_put_ = {
 		"Comment": ((102, LCID, 4, 0),()),
@@ -2131,34 +2143,34 @@ ITire_vtables_ = [
 
 ITireGeometryRim_vtables_dispatch_ = 1
 ITireGeometryRim_vtables_ = [
-	(( 'RimWidth' , 'ppVal' , ), 4051, (4051, (), [ (16393, 10, None, "IID('{2B5166E3-4B31-4607-B157-BE237A670336}')") , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
-	(( 'RimDiameter' , 'ppVal' , ), 4052, (4052, (), [ (16393, 10, None, "IID('{2B5166E3-4B31-4607-B157-BE237A670336}')") , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
-	(( 'RimWidthUnitMM' , 'pVal' , ), 4053, (4053, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
-	(( 'RimWidthUnitMM' , 'pVal' , ), 4053, (4053, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
-	(( 'RimDiameterUnitInch' , 'pVal' , ), 4054, (4054, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
-	(( 'RimDiameterUnitInch' , 'pVal' , ), 4054, (4054, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
+	(( 'RimWidth' , 'ppVal' , ), 4051, (4051, (), [ (16393, 10, None, "IID('{2B5166E3-4B31-4607-B157-BE237A670336}')") , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
+	(( 'RimDiameter' , 'ppVal' , ), 4052, (4052, (), [ (16393, 10, None, "IID('{2B5166E3-4B31-4607-B157-BE237A670336}')") , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
+	(( 'RimWidthUnitMM' , 'pVal' , ), 4053, (4053, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
+	(( 'RimWidthUnitMM' , 'pVal' , ), 4053, (4053, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
+	(( 'RimDiameterUnitInch' , 'pVal' , ), 4054, (4054, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
+	(( 'RimDiameterUnitInch' , 'pVal' , ), 4054, (4054, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
 ]
 
 ITireGeometryRimGeneric_vtables_dispatch_ = 1
 ITireGeometryRimGeneric_vtables_ = [
-	(( 'NumberOfLeads' , 'pVal' , ), 4101, (4101, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
-	(( 'NumberOfLeads' , 'pVal' , ), 4101, (4101, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
-	(( 'AngleOfRimHole' , 'ppVal' , ), 4102, (4102, (), [ (16393, 10, None, "IID('{2B5166E3-4B31-4607-B157-BE237A670336}')") , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
-	(( 'RimInnerDiameter' , 'ppVal' , ), 4103, (4103, (), [ (16393, 10, None, "IID('{2B5166E3-4B31-4607-B157-BE237A670336}')") , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
-	(( 'RimInnerDiameterUnitInch' , 'pVal' , ), 4104, (4104, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
-	(( 'RimInnerDiameterUnitInch' , 'pVal' , ), 4104, (4104, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
+	(( 'NumberOfLeads' , 'pVal' , ), 4101, (4101, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
+	(( 'NumberOfLeads' , 'pVal' , ), 4101, (4101, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
+	(( 'AngleOfRimHole' , 'ppVal' , ), 4102, (4102, (), [ (16393, 10, None, "IID('{2B5166E3-4B31-4607-B157-BE237A670336}')") , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
+	(( 'RimInnerDiameter' , 'ppVal' , ), 4103, (4103, (), [ (16393, 10, None, "IID('{2B5166E3-4B31-4607-B157-BE237A670336}')") , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
+	(( 'RimInnerDiameterUnitInch' , 'pVal' , ), 4104, (4104, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
+	(( 'RimInnerDiameterUnitInch' , 'pVal' , ), 4104, (4104, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
 ]
 
 ITireGeometryTire_vtables_dispatch_ = 1
 ITireGeometryTire_vtables_ = [
-	(( 'SectionWidth' , 'ppVal' , ), 4051, (4051, (), [ (16393, 10, None, "IID('{2B5166E3-4B31-4607-B157-BE237A670336}')") , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
-	(( 'AspectRatio' , 'ppVal' , ), 4052, (4052, (), [ (16393, 10, None, "IID('{2B5166E3-4B31-4607-B157-BE237A670336}')") , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
-	(( 'RimDiameter' , 'ppVal' , ), 4053, (4053, (), [ (16393, 10, None, "IID('{2B5166E3-4B31-4607-B157-BE237A670336}')") , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
-	(( 'SectionWidthUnitMM' , 'pVal' , ), 4054, (4054, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
-	(( 'SectionWidthUnitMM' , 'pVal' , ), 4054, (4054, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
-	(( 'RimDiameterUnitInch' , 'pVal' , ), 4055, (4055, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
-	(( 'RimDiameterUnitInch' , 'pVal' , ), 4055, (4055, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
-	(( 'UpdateTireRadius' , ), 4056, (4056, (), [ ], 1 , 1 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
+	(( 'SectionWidth' , 'ppVal' , ), 4051, (4051, (), [ (16393, 10, None, "IID('{2B5166E3-4B31-4607-B157-BE237A670336}')") , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
+	(( 'AspectRatio' , 'ppVal' , ), 4052, (4052, (), [ (16393, 10, None, "IID('{2B5166E3-4B31-4607-B157-BE237A670336}')") , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
+	(( 'RimDiameter' , 'ppVal' , ), 4053, (4053, (), [ (16393, 10, None, "IID('{2B5166E3-4B31-4607-B157-BE237A670336}')") , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
+	(( 'SectionWidthUnitMM' , 'pVal' , ), 4054, (4054, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
+	(( 'SectionWidthUnitMM' , 'pVal' , ), 4054, (4054, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
+	(( 'RimDiameterUnitInch' , 'pVal' , ), 4055, (4055, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
+	(( 'RimDiameterUnitInch' , 'pVal' , ), 4055, (4055, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
+	(( 'UpdateTireRadius' , ), 4056, (4056, (), [ ], 1 , 1 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
 ]
 
 ITireGroup_vtables_dispatch_ = 1
